===========
Model Logs
===========

Model logs is a Django app for storing changes of yours objects

Quick start
-----------

1. Add "model_log" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'model_log',
    ]


2. Run ``python manage.py migrate`` to create the "model_logs" models.

